#!/bin/sh -x

if [ $# != 1 ]; then
  echo "Usage: $0 install_dir"
  exit 1
fi

instdir="$1"
# these paths can be safely changed
sources=`dirname $0`/sources
build=`pwd`/build

test -d "$sources" || { echo "Source directory not found"; exit 1; }
mkdir -p "$build" "$instdir"
# all path must be absolute
sources=`(cd "$sources" && pwd)`
build=`(cd "$build" && pwd)`
instdir=`(cd "$instdir" && pwd)`

UNAME_SYSTEM=`uname -s`
case "$UNAME_SYSTEM" in
    MINGW*|Windows*|windows*)
        os="win" ;;
    *)
        os="unix" ;;
esac

if [ $UNAME_SYSTEM = Darwin -a -d /usr/X11/include ]; then
    XDIRS="--x-includes=/usr/X11/include --x-libraries=/usr/X11/lib"
fi

if [ $UNAME_SYSTEM = Linux ]; then
    export LDFLAGS="${LDFLAGS:-'-Wl,-rpath,\$$ORIGIN/../lib'}"
fi

echo "Tcl and Tk have two configure scripts, we will use: $os/configure"

# Building Tcl 8.4
mkdir -p $build/tcl && cd $build/tcl
$sources/tcl8*/$os/configure --prefix="$instdir"  || exit 1
make && make install || exit 1
cd "$instdir"/bin
if [ $os = win ]; then
  ln -s tclsh84 tclsh
else
  ln -s tclsh8.4 tclsh
fi

# Building Tk 8.4
mkdir -p $build/tk && cd $build/tk
$sources/tk8*/$os/configure --prefix="$instdir" --with-tcl=$build/tcl  || exit 1
make && make install || exit 1
cd "$instdir"/bin
if [ $os = win ]; then
  ln -s wish84 wish
else
  ln -s wish8.4 wish
fi

# Building blt 2.4z (patched)
mkdir -p $build/blt && cd $build/blt
$sources/blt2.4z/configure --prefix="$instdir" $XDIRS || exit 1
make && make install || exit 1
# on Windows/mingw bin/bltsh and bin/bltwish are not installed
if [ $os = win ]; then
  cd "$instdir"/bin
  ln -s bltsh24 bltsh
  ln -s bltwish24 bltwish
fi

# Building IncrTcl (includes Itk)
mkdir -p $build/itcl && cd $build/itcl
$sources/itcl*/configure --prefix="$instdir" --with-tcl="$instdir/lib" \
                                             --with-tk="$instdir/lib" || exit 1
make && make install || exit 1


# Building iwidget
mkdir -p $build/iwidgets && cd $build/iwidgets
PATH="$instdir"/bin:$PATH \
$sources/iwidgets-*/configure --prefix="$instdir" \
                              --with-tcl="$instdir/lib" \
                              --with-tk="$instdir/lib" \
                              --with-itcl=$sources/itcl*/itcl \
                              --with-itk=$sources/itcl*/itk   || exit 1
# no make, iwidgets is a collection of scripts
make install || exit 1

# Building tDom
mkdir -p $build/tdom && cd $build/tdom
$sources/tDOM*/configure --prefix="$instdir" --with-tcl="$instdir/lib" \
                                             --with-tk="$instdir/lib" || exit 1
make && make install || exit 1


# Building tkImg
mkdir -p $build/tkimg && cd $build/tkimg
$sources/tkimg*/configure --prefix="$instdir" --with-tcl="$instdir/lib" \
                                              --with-tk="$instdir/lib" || exit 1
# installing manual requires dtplite, get rid of it
sed -i -e 's/dtplite/true/' Makefile
make && make install || exit 1

# Building tktreectrl
mkdir -p $build/tktreectrl && cd $build/tktreectrl
$sources/tktreectrl*/configure --prefix="$instdir" --with-tcl="$instdir/lib" \
                                            --with-tk="$instdir/lib"  || exit 1
make && make install || exit 1


# add licenses
mkdir "$instdir"/licenses
cp $sources/tcl8*/license.terms          "$instdir"/licenses/License-tcl
cp $sources/tk8*/license.terms           "$instdir"/licenses/License-tk
cp $sources/itcl*/license.terms          "$instdir"/licenses/License-itcl
cp $sources/iwidgets-*/license.terms     "$instdir"/licenses/License-iwidgets
cp $sources/tktreectrl*/license.terms    "$instdir"/licenses/License-tktreectrl
cp $sources/tkimg*/license.terms         "$instdir"/licenses/License-tkimg
cp $sources/tDOM*/LICENSE                "$instdir"/licenses/License-tDOM

